# CHANGES



## v0.4.0

+ Enable using PSF from python.
+ remove dependency on jax


## v0.5.0
+ Returns M00, M20 and their shear responses
+ Detections can have double coordinates in image plane
+ remove dependence on FPFS for unit tests
+ Enable Force measurement

## v0.5.1
+ Change the definition of the input smoothness parameter for differentiable
  cuts

## v0.5.2
+ Add option for base column name
+ Change column name to fpfs_de_dg
